==> py-martel-0.3.5%2C1.tgz: lib/python2.0/site-packages/Martel/test/test_blastall_2_0_10.py <==
from Martel.formats.blastall_2_0_10 import *
from Martel import Generate

import os
import support

dirname = "/home/dalke/cvses/biopython/Tests/Blast"


test_list = support.Storage()

add_test = test_list.add_test

add_test("version", version, """\
BLASTP 2.0.10 [Aug-26-1999]
""")

add_test("reference", reference, """\
Reference: Altschul, Stephen F., Thomas L. Madden, Alejandro A. Schaffer, 
Jinghui Zhang, Zheng Zhang, Webb Miller, and David J. Lipman (1997), 
"Gapped BLAST and PSI-BLAST: a new generation of protein database search
programs",  Nucleic Acids Res. 25:3389-3402.
""")

add_test("query_info 1", query_info, """\
Query= gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN
         (141 letters)
""")

add_test("query_info 2", query_info, """\
Query= gi|400206|sp|Q02112|LYTA_BACSU MEMBRANE-BOUND PROTEIN LYTA
PRECURSOR
         (102 letters)
""")

add_test("database", database, """\
Database: data/swissprot
           82,258 sequences; 29,652,561 total letters
""")

add_test("index_line (rep)", Rep(index_line), """\
gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN                          284  7e-77
gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958 PRE...    29  3.4
""")

add_test("index", index, """\
                                                                   Score     E
Sequences producing significant alignments:                        (bits)  Value

gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN                          284  7e-77
gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958 PRE...    29  3.4
gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A         29  4.5
""")


s1 = ">gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN\n"
s2 = "           Length = 141\n"
s3 = "           \n"
s4 = " Score =  284 bits (718), Expect = 7e-77\n"
s5 = " Identities = 141/141 (100%), Positives = 141/141 (100%)\n"


add_test("hit_desc", hit_desc, s1)
add_test("hit_description", hit_description, s1)
add_test("hit_length", hit_length, s2)
add_test("hit description and length", hit_description + hit_length,
          s1 + s2)
add_test("that indented line", Re(r" *\n"), s3)
add_test("hit score 1", hit1, s4)
add_test("hit score 2", hit1, """\
 Score = 29.0 bits (63), Expect = 4.5
""")
add_test("hit identies 1", hit2, s5)
add_test("hit identies 2", hit2, """\
 Identities = 31/107 (28%), Positives = 46/107 (42%), Gaps = 9/107 (8%)
""")
add_test("hit_header", hit_header, s1+s2+s3)
add_test("subhit_header", subhit_header, s4+s5)

add_test("alignment 1", query_line + midline + sbjct_line, """\
Query: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60
           MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV
Sbjct: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60
""")
add_test("alignment 2", query_line + midline + sbjct_line, """\
Query: 94  LQDCIAISKHVMAREYYKALMLSRKLIEYEDERLGHVSSGVSAGGDA 140
           L+D     + V+A      + ++RKL EY D   G     VSA  DA
Sbjct: 395 LED-----REVVAGGGAPEVEIARKLREYADTISGREQLAVSAFADA 436
""")

add_test("hit 1", hit, """\
>gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A
           Length = 542
           
 Score = 29.0 bits (63), Expect = 4.5
 Identities = 31/107 (28%), Positives = 46/107 (42%), Gaps = 9/107 (8%)

Query: 34  KASVLREKDIMQPDQVTTPARHIYFPVMMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVV 93
           +A V+ EK I   D+V T       P  +  +     +   EE    L + +GVV +   
Sbjct: 339 EAGVIYEKKIF--DEVLTFIEECRDPKAISIILRGSTKHVAEEMERALEDAIGVVAS--T 394

Query: 94  LQDCIAISKHVMAREYYKALMLSRKLIEYEDERLGHVSSGVSAGGDA 140
           L+D     + V+A      + ++RKL EY D   G     VSA  DA
Sbjct: 395 LED-----REVVAGGGAPEVEIARKLREYADTISGREQLAVSAFADA 436


""")

add_test("statistics1", statistics1, """\
  Database: data/swissprot
    Posted date:  Nov 15, 1999  2:55 PM
  Number of letters in database: 29,652,561
  Number of sequences in database:  82,258
  
""")
add_test("statistics2", statistics2, """\
Lambda     K      H
   0.321    0.138    0.390 

Lambda     K      H
   0.270   0.0470    0.230 


""")
add_test("statistics3", statistics3, """\
Matrix: BLOSUM62
Gap Penalties: Existence: 11, Extension: 1
Number of Hits to DB: 7927717
Number of Sequences: 82258
Number of extensions: 284596
Number of successful extensions: 567
Number of sequences better than 10.0: 3
Number of HSP's better than 10.0 without gapping: 2
Number of HSP's successfully gapped in prelim test: 1
Number of HSP's that attempted gapping in prelim test: 565
Number of HSP's gapped (non-prelim): 3
""")

add_test("statistics4", statistics4, """\
length of query: 141
length of database: 29,652,561
effective HSP length: 50
effective length of query: 91
effective length of database: 25,539,661
effective search space: 2324109151
effective search space used: 2324109151
T: 11
A: 40
X1: 16 ( 7.4 bits)
X2: 38 (14.8 bits)
X3: 64 (24.9 bits)
S1: 41 (21.8 bits)
S2: 61 (28.2 bits)
""")

add_test("format 1", format, """\
BLASTP 2.0.10 [Aug-26-1999]


Reference: Altschul, Stephen F., Thomas L. Madden, Alejandro A. Schaffer, 
Jinghui Zhang, Zheng Zhang, Webb Miller, and David J. Lipman (1997), 
"Gapped BLAST and PSI-BLAST: a new generation of protein database search
programs",  Nucleic Acids Res. 25:3389-3402.

Query= gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN
         (141 letters)

Database: data/swissprot
           82,258 sequences; 29,652,561 total letters

Searching..................................................done

                                                                   Score     E
Sequences producing significant alignments:                        (bits)  Value

gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN                          284  7e-77
gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958 PRE...    29  3.4
gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A         29  4.5

>gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN
           Length = 141
           
 Score =  284 bits (718), Expect = 7e-77
 Identities = 141/141 (100%), Positives = 141/141 (100%)

Query: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60
           MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV
Sbjct: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60

Query: 61  MMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVVLQDCIAISKHVMAREYYKALMLSRKLI 120
           MMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVVLQDCIAISKHVMAREYYKALMLSRKLI
Sbjct: 61  MMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVVLQDCIAISKHVMAREYYKALMLSRKLI 120

Query: 121 EYEDERLGHVSSGVSAGGDAG 141
           EYEDERLGHVSSGVSAGGDAG
Sbjct: 121 EYEDERLGHVSSGVSAGGDAG 141


>gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958
           PRECURSOR
           Length = 426
           
 Score = 29.3 bits (64), Expect = 3.4
 Identities = 15/47 (31%), Positives = 23/47 (48%)

Query: 28  VLVLQNKASVLREKDIMQPDQVTTPARHIYFPVMMMYLDEVGAEKFY 74
           +LVL N  ++   K     D  TT   +IY P+ +    +  A+KFY
Sbjct: 169 ILVLINNTNITELKKFEDDDYYTTFQHYIYQPIFIFTTYDSKAKKFY 215


>gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A
           Length = 542
           
 Score = 29.0 bits (63), Expect = 4.5
 Identities = 31/107 (28%), Positives = 46/107 (42%), Gaps = 9/107 (8%)

Query: 34  KASVLREKDIMQPDQVTTPARHIYFPVMMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVV 93
           +A V+ EK I   D+V T       P  +  +     +   EE    L + +GVV +   
Sbjct: 339 EAGVIYEKKIF--DEVLTFIEECRDPKAISIILRGSTKHVAEEMERALEDAIGVVAS--T 394

Query: 94  LQDCIAISKHVMAREYYKALMLSRKLIEYEDERLGHVSSGVSAGGDA 140
           L+D     + V+A      + ++RKL EY D   G     VSA  DA
Sbjct: 395 LED-----REVVAGGGAPEVEIARKLREYADTISGREQLAVSAFADA 436


  Database: data/swissprot
    Posted date:  Nov 15, 1999  2:55 PM
  Number of letters in database: 29,652,561
  Number of sequences in database:  82,258
  
Lambda     K      H
   0.321    0.138    0.390 

Lambda     K      H
   0.270   0.0470    0.230 


Matrix: BLOSUM62
Gap Penalties: Existence: 11, Extension: 1
Number of Hits to DB: 7927717
Number of Sequences: 82258
Number of extensions: 284596
Number of successful extensions: 567
Number of sequences better than 10.0: 3
Number of HSP's better than 10.0 without gapping: 2
Number of HSP's successfully gapped in prelim test: 1
Number of HSP's that attempted gapping in prelim test: 565
Number of HSP's gapped (non-prelim): 3
length of query: 141
length of database: 29,652,561
effective HSP length: 50
effective length of query: 91
effective length of database: 25,539,661
effective search space: 2324109151
effective search space used: 2324109151
T: 11
A: 40
X1: 16 ( 7.4 bits)
X2: 38 (14.8 bits)
X3: 64 (24.9 bits)
S1: 41 (21.8 bits)
S2: 61 (28.2 bits)
""")

add_test("format 2", format, """\
BLASTP 2.0.10 [Aug-26-1999]


Reference: Altschul, Stephen F., Thomas L. Madden, Alejandro A. Schaffer, 
Jinghui Zhang, Zheng Zhang, Webb Miller, and David J. Lipman (1997), 
"Gapped BLAST and PSI-BLAST: a new generation of protein database search
programs",  Nucleic Acids Res. 25:3389-3402.

Query= gi|400206|sp|Q02112|LYTA_BACSU MEMBRANE-BOUND PROTEIN LYTA
PRECURSOR
         (102 letters)

Database: data/pdbaa
           6999 sequences; 1,461,753 total letters

Searching..................................................done

 ***** No hits found ******

  Database: data/pdbaa
    Posted date:  Oct 11, 1999 11:30 AM
  Number of letters in database: 1,461,753
  Number of sequences in database:  6999
  
Lambda     K      H
   0.310    0.132    0.353 

Lambda     K      H
   0.270   0.0470    0.230 


Matrix: BLOSUM62
Gap Penalties: Existence: 11, Extension: 1
Number of Hits to DB: 289135
Number of Sequences: 6999
Number of extensions: 10742
Number of successful extensions: 10
Number of sequences better than 10.0: 0
Number of HSP's better than 10.0 without gapping: 0
Number of HSP's successfully gapped in prelim test: 0
Number of HSP's that attempted gapping in prelim test: 10
Number of HSP's gapped (non-prelim): 0
length of query: 102
length of database: 1,461,753
effective HSP length: 45
effective length of query: 57
effective length of database: 1,146,798
effective search space: 65367486
effective search space used: 65367486
T: 11
A: 40
X1: 16 ( 7.1 bits)
X2: 38 (14.8 bits)
X3: 64 (24.9 bits)
S1: 42 (21.7 bits)
S2: 47 (22.7 bits)
""")

def test_file(filename, parser):
    infile = open(filename)
    parser.parseFile(infile)
    infile.close()

def dump_file(filename):
    parser = Generate.generate_parser(format)
    import sys
    dump = support.Dump(sys.stdout)
    parser.setContentHandler(dump)
    parser.setErrorHandler(dump)
    test_file(os.path.join(dirname, filename), parser)

def test_files():
    parser = Generate.generate_parser(format)
    good = support.CheckGood()
    parser.setContentHandler(good)
    parser.setErrorHandler(good)
    # I don't understand what bt005 does
    for filename in ["bt001", "bt002", "bt003", "bt004",
                     "bt010", "bt010", "bt011", "bt012",
                     "bt014", "bt015", "bt016", "bt017",
                     "bt018", 
                     ]:
        test_file(os.path.join(dirname, filename), parser)
        if good.good_parse:
            print filename, "was good"
        else:
            print filename, "was bad"

def test():
    test_list.test()

def dump():
    test_list.dump()

==> py-martel-0.5_2%2C1.tgz: lib/python2.0/site-packages/Martel/test/test_blastall_2_0_10.py <==
from Martel.formats.blastall_2_0_10 import *
from Martel import Generate

import os
import support

dirname = "/home/dalke/cvses/biopython/Tests/Blast"


test_list = support.Storage()

add_test = test_list.add_test

add_test("version", version, """\
BLASTP 2.0.10 [Aug-26-1999]
""")

add_test("reference", reference, """\
Reference: Altschul, Stephen F., Thomas L. Madden, Alejandro A. Schaffer, 
Jinghui Zhang, Zheng Zhang, Webb Miller, and David J. Lipman (1997), 
"Gapped BLAST and PSI-BLAST: a new generation of protein database search
programs",  Nucleic Acids Res. 25:3389-3402.
""")

add_test("query_info 1", query_info, """\
Query= gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN
         (141 letters)
""")

add_test("query_info 2", query_info, """\
Query= gi|400206|sp|Q02112|LYTA_BACSU MEMBRANE-BOUND PROTEIN LYTA
PRECURSOR
         (102 letters)
""")

add_test("database", database, """\
Database: data/swissprot
           82,258 sequences; 29,652,561 total letters
""")

add_test("index_line (rep)", Rep(index_line), """\
gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN                          284  7e-77
gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958 PRE...    29  3.4
""")

add_test("index", index, """\
                                                                   Score     E
Sequences producing significant alignments:                        (bits)  Value

gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN                          284  7e-77
gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958 PRE...    29  3.4
gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A         29  4.5
""")


s1 = ">gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN\n"
s2 = "           Length = 141\n"
s3 = "           \n"
s4 = " Score =  284 bits (718), Expect = 7e-77\n"
s5 = " Identities = 141/141 (100%), Positives = 141/141 (100%)\n"


add_test("hit_desc", hit_desc, s1)
add_test("hit_description", hit_description, s1)
add_test("hit_length", hit_length, s2)
add_test("hit description and length", hit_description + hit_length,
          s1 + s2)
add_test("that indented line", Re(r" *\R"), s3)
add_test("hit score 1", hit1, s4)
add_test("hit score 2", hit1, """\
 Score = 29.0 bits (63), Expect = 4.5
""")
add_test("hit identies 1", hit2, s5)
add_test("hit identies 2", hit2, """\
 Identities = 31/107 (28%), Positives = 46/107 (42%), Gaps = 9/107 (8%)
""")
add_test("hit_header", hit_header, s1+s2+s3)
add_test("subhit_header", subhit_header, s4+s5)

add_test("alignment 1", query_line + midline + sbjct_line, """\
Query: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60
           MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV
Sbjct: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60
""")
add_test("alignment 2", query_line + midline + sbjct_line, """\
Query: 94  LQDCIAISKHVMAREYYKALMLSRKLIEYEDERLGHVSSGVSAGGDA 140
           L+D     + V+A      + ++RKL EY D   G     VSA  DA
Sbjct: 395 LED-----REVVAGGGAPEVEIARKLREYADTISGREQLAVSAFADA 436
""")

add_test("hit 1", hit, """\
>gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A
           Length = 542
           
 Score = 29.0 bits (63), Expect = 4.5
 Identities = 31/107 (28%), Positives = 46/107 (42%), Gaps = 9/107 (8%)

Query: 34  KASVLREKDIMQPDQVTTPARHIYFPVMMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVV 93
           +A V+ EK I   D+V T       P  +  +     +   EE    L + +GVV +   
Sbjct: 339 EAGVIYEKKIF--DEVLTFIEECRDPKAISIILRGSTKHVAEEMERALEDAIGVVAS--T 394

Query: 94  LQDCIAISKHVMAREYYKALMLSRKLIEYEDERLGHVSSGVSAGGDA 140
           L+D     + V+A      + ++RKL EY D   G     VSA  DA
Sbjct: 395 LED-----REVVAGGGAPEVEIARKLREYADTISGREQLAVSAFADA 436


""")

add_test("statistics1", statistics1, """\
  Database: data/swissprot
    Posted date:  Nov 15, 1999  2:55 PM
  Number of letters in database: 29,652,561
  Number of sequences in database:  82,258
  
""")
add_test("statistics2", statistics2, """\
Lambda     K      H
   0.321    0.138    0.390 

Lambda     K      H
   0.270   0.0470    0.230 


""")
add_test("statistics3", statistics3, """\
Matrix: BLOSUM62
Gap Penalties: Existence: 11, Extension: 1
Number of Hits to DB: 7927717
Number of Sequences: 82258
Number of extensions: 284596
Number of successful extensions: 567
Number of sequences better than 10.0: 3
Number of HSP's better than 10.0 without gapping: 2
Number of HSP's successfully gapped in prelim test: 1
Number of HSP's that attempted gapping in prelim test: 565
Number of HSP's gapped (non-prelim): 3
""")

add_test("statistics4", statistics4, """\
length of query: 141
length of database: 29,652,561
effective HSP length: 50
effective length of query: 91
effective length of database: 25,539,661
effective search space: 2324109151
effective search space used: 2324109151
T: 11
A: 40
X1: 16 ( 7.4 bits)
X2: 38 (14.8 bits)
X3: 64 (24.9 bits)
S1: 41 (21.8 bits)
S2: 61 (28.2 bits)
""")

add_test("format 1", format, """\
BLASTP 2.0.10 [Aug-26-1999]


Reference: Altschul, Stephen F., Thomas L. Madden, Alejandro A. Schaffer, 
Jinghui Zhang, Zheng Zhang, Webb Miller, and David J. Lipman (1997), 
"Gapped BLAST and PSI-BLAST: a new generation of protein database search
programs",  Nucleic Acids Res. 25:3389-3402.

Query= gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN
         (141 letters)

Database: data/swissprot
           82,258 sequences; 29,652,561 total letters

Searching..................................................done

                                                                   Score     E
Sequences producing significant alignments:                        (bits)  Value

gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN                          284  7e-77
gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958 PRE...    29  3.4
gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A         29  4.5

>gi|120291|sp|P21297|FLBT_CAUCR FLBT PROTEIN
           Length = 141
           
 Score =  284 bits (718), Expect = 7e-77
 Identities = 141/141 (100%), Positives = 141/141 (100%)

Query: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60
           MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV
Sbjct: 1   MPLKLSLKPGEKFVLNGAVVQNGDRRGVLVLQNKASVLREKDIMQPDQVTTPARHIYFPV 60

Query: 61  MMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVVLQDCIAISKHVMAREYYKALMLSRKLI 120
           MMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVVLQDCIAISKHVMAREYYKALMLSRKLI
Sbjct: 61  MMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVVLQDCIAISKHVMAREYYKALMLSRKLI 120

Query: 121 EYEDERLGHVSSGVSAGGDAG 141
           EYEDERLGHVSSGVSAGGDAG
Sbjct: 121 EYEDERLGHVSSGVSAGGDAG 141


>gi|3024946|sp|Q58368|Y958_METJA HYPOTHETICAL PROTEIN MJ0958
           PRECURSOR
           Length = 426
           
 Score = 29.3 bits (64), Expect = 3.4
 Identities = 15/47 (31%), Positives = 23/47 (48%)

Query: 28  VLVLQNKASVLREKDIMQPDQVTTPARHIYFPVMMMYLDEVGAEKFY 74
           +LVL N  ++   K     D  TT   +IY P+ +    +  A+KFY
Sbjct: 169 ILVLINNTNITELKKFEDDDYYTTFQHYIYQPIFIFTTYDSKAKKFY 215


>gi|3024745|sp|O26320|THSA_METTH PROBABLE THERMOSOME SUBUNIT A
           Length = 542
           
 Score = 29.0 bits (63), Expect = 4.5
 Identities = 31/107 (28%), Positives = 46/107 (42%), Gaps = 9/107 (8%)

Query: 34  KASVLREKDIMQPDQVTTPARHIYFPVMMMYLDEVGAEKFYEEFATRLNEFMGVVRNPVV 93
           +A V+ EK I   D+V T       P  +  +     +   EE    L + +GVV +   
Sbjct: 339 EAGVIYEKKIF--DEVLTFIEECRDPKAISIILRGSTKHVAEEMERALEDAIGVVAS--T 394

Query: 94  LQDCIAISKHVMAREYYKALMLSRKLIEYEDERLGHVSSGVSAGGDA 140
           L+D     + V+A      + ++RKL EY D   G     VSA  DA
Sbjct: 395 LED-----REVVAGGGAPEVEIARKLREYADTISGREQLAVSAFADA 436


  Database: data/swissprot
    Posted date:  Nov 15, 1999  2:55 PM
  Number of letters in database: 29,652,561
  Number of sequences in database:  82,258
  
Lambda     K      H
   0.321    0.138    0.390 

Lambda     K      H
   0.270   0.0470    0.230 


Matrix: BLOSUM62
Gap Penalties: Existence: 11, Extension: 1
Number of Hits to DB: 7927717
Number of Sequences: 82258
Number of extensions: 284596
Number of successful extensions: 567
Number of sequences better than 10.0: 3
Number of HSP's better than 10.0 without gapping: 2
Number of HSP's successfully gapped in prelim test: 1
Number of HSP's that attempted gapping in prelim test: 565
Number of HSP's gapped (non-prelim): 3
length of query: 141
length of database: 29,652,561
effective HSP length: 50
effective length of query: 91
effective length of database: 25,539,661
effective search space: 2324109151
effective search space used: 2324109151
T: 11
A: 40
X1: 16 ( 7.4 bits)
X2: 38 (14.8 bits)
X3: 64 (24.9 bits)
S1: 41 (21.8 bits)
S2: 61 (28.2 bits)
""")

add_test("format 2", format, """\
BLASTP 2.0.10 [Aug-26-1999]


Reference: Altschul, Stephen F., Thomas L. Madden, Alejandro A. Schaffer, 
Jinghui Zhang, Zheng Zhang, Webb Miller, and David J. Lipman (1997), 
"Gapped BLAST and PSI-BLAST: a new generation of protein database search
programs",  Nucleic Acids Res. 25:3389-3402.

Query= gi|400206|sp|Q02112|LYTA_BACSU MEMBRANE-BOUND PROTEIN LYTA
PRECURSOR
         (102 letters)

Database: data/pdbaa
           6999 sequences; 1,461,753 total letters

Searching..................................................done

 ***** No hits found ******

  Database: data/pdbaa
    Posted date:  Oct 11, 1999 11:30 AM
  Number of letters in database: 1,461,753
  Number of sequences in database:  6999
  
Lambda     K      H
   0.310    0.132    0.353 

Lambda     K      H
   0.270   0.0470    0.230 


Matrix: BLOSUM62
Gap Penalties: Existence: 11, Extension: 1
Number of Hits to DB: 289135
Number of Sequences: 6999
Number of extensions: 10742
Number of successful extensions: 10
Number of sequences better than 10.0: 0
Number of HSP's better than 10.0 without gapping: 0
Number of HSP's successfully gapped in prelim test: 0
Number of HSP's that attempted gapping in prelim test: 10
Number of HSP's gapped (non-prelim): 0
length of query: 102
length of database: 1,461,753
effective HSP length: 45
effective length of query: 57
effective length of database: 1,146,798
effective search space: 65367486
effective search space used: 65367486
T: 11
A: 40
X1: 16 ( 7.1 bits)
X2: 38 (14.8 bits)
X3: 64 (24.9 bits)
S1: 42 (21.7 bits)
S2: 47 (22.7 bits)
""")

def test_file(filename, parser):
    infile = open(filename)
    parser.parseFile(infile)
    infile.close()

def dump_file(filename):
    parser = Generate.generate_parser(format)
    import sys
    dump = support.Dump(sys.stdout)
    parser.setContentHandler(dump)
    parser.setErrorHandler(dump)
    test_file(os.path.join(dirname, filename), parser)

def test_files():
    parser = Generate.generate_parser(format)
    good = support.CheckGood()
    parser.setContentHandler(good)
    parser.setErrorHandler(good)
    # I don't understand what bt005 does
    for filename in ["bt001", "bt002", "bt003", "bt004",
                     "bt010", "bt010", "bt011", "bt012",
                     "bt014", "bt015", "bt016", "bt017",
                     "bt018", 
                     ]:
        test_file(os.path.join(dirname, filename), parser)
        if good.good_parse:
            print filename, "was good"
        else:
            print filename, "was bad"

def test():
    test_list.test(debug_level = 0)

def dump():
    test_list.dump()

if __name__ == "__main__":
    test()
